;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
;	6800 macro for PIC16F
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
;
LDXI	macro	var
	movlw	HIGH(var)
	movwf	FSR0H
	movlw	LOW(var)
	movwf	FSR0L
	endm

LDX	macro	var
	movf	var,W
	movwf	FSR0H
	movf	var+1,W
	movwf	FSR0L
	endm

STX	macro	var
	movf	FSR0H,W
	movwf	var
	movf	FSR0L,W
	movwf	var+1
	endm

CMPAI	macro	var
        movlw	var
	subwf	Areg,W
	endm

CMPBI	macro	var
        movlw	var
	subwf	Breg,W
	endm

CMPA	macro	var
        movf	var,W
	subwf	Areg,W
	endm

CMPB	macro	var
        movf	var,W
	subwf	Breg,W
	endm

SUBAI	macro	var
        movlw	var
	subwf	Areg,F
	endm

SUBA	macro	var
        movf	var,W
	subwf	Areg,F
	endm

LDAA	macro	var
	movf	var,W
	movwf	Areg
	endm

STAA	macro	var
	movf	Areg,W
	movwf	var
	endm

ADDAI	macro	var
	movlw	var
	addwf	Areg,F
	endm

ADDBI	macro	var
	movlw	var
	addwf	Breg,F
	endm

ANDAI	macro	var
	movlw	var
	andwf	Areg,F
	endm

ANDBI	macro	var
	movlw	var
	andwf	Breg,F
	endm

ADDA	macro	var
	movf	var,W
	addwf	Areg,F
	endm

ADDB	macro	var
	movf	var,W
	addwf	Breg,F
	endm

DECB	macro
	decf	Breg,F
	endm

DEC	macro	var
	decf	var,F
	endm

STAB	macro	var
	movf	Breg,W
	movwf	var
	endm

LDAAI	macro	var
	movlw	var
	movwf	Areg
	endm

LDABI	macro	var
	movlw	var
	movwf	Breg
	endm

LDAB	macro	var
	movf	var,W
	movwf	Breg
	endm

CPXI	macro	var
	movlw	LOW(var)
	subwf	FSR0L,W
	skpz
	bra	$+3
	movlw	HIGH(var)
	subwf	FSR0H,W
	endm

CPX	macro	var
	movf	var+1,W
	subwf	FSR0L,W
	skpz
	bra	$+3
	movf	var,W
	subwf	FSR0H,W
	endm

LDSI	macro	var
	movlw	HIGH(var)
	movwf	FSR1H
	movlw	LOW(var)
	movwf	FSR1L
	endm

LDS	macro	var
	movf	var,W
	movwf	FSR1H
	movf	var+1,W
	movwf	FSR1L
	endm

STS	macro	var
	movf	FSR1H,W
	movwf	var
	movf	FSR1L,W
	movwf	var+1
	endm

TXS	macro
        movf	FSR0H,W
	movwf	FSR1H
        movf	FSR0L,W
	movwf	FSR1L
	addfsr	FSR1,-1
	endm

TSX	macro
        movf	FSR1H,W
	movwf	FSR0H
        movf	FSR1L,W
	movwf	FSR0L
	addfsr	FSR0,1
	endm

PSHA	macro
	movf	Areg,W
	movwi	INDF1--
	endm

PULA	macro
        moviw	++INDF1
	movwf	Areg
	endm

PSHB	macro
	movf	Breg,W
	movwi	INDF1--
	endm

PULB	macro
        moviw	++INDF1
	movwf	Breg
	endm

ADCAI	macro	var
	movlw	var
	addwfc	Areg,F
	endm

ADCBI	macro	var
	movlw	var
	addwfc	Breg,F
	endm

ADCB	macro	var
	movf	var,W
	addwfc	Breg,F
	endm

SBCBI	macro	var
	movlw	var
	subwfb	Breg,F
	endm

SBCB	macro	var
	movf	var,W
	subwfb	Breg,F
	endm

BITAI	macro	var
        movlw	var
	andwf	Areg,W
	endm

BITBI	macro	var
        movlw	var
	andwf	Breg,W
	endm

EORA	macro	var
	movf	var,W
	xorwf	Areg,F
	endm

EORAI	macro	var
	movlw	var
	xorwf	Areg,F
	endm

TAB	macro
	movf	Areg,W
	movwf	Breg
	endm

TBA	macro
	movf	Breg,W
	movwf	Areg
	endm

COMA	macro
        comf	Areg,F
	endm

NEGA	macro
	comf	Areg,F
	incf	Areg,F
	endm

TPA	macro
	swapf	STATUS,W
	swapf	WREG,W
	movwf	Areg
	endm

INX	macro
	addfsr	FSR0,1
	endm

DEX	macro
	addfsr	FSR0,-1
	endm

INS	macro
	addfsr	FSR1,1
	endm

DES	macro
	addfsr	FSR1,-1
	endm

TST	macro	var
        movf	var,W
	endm

TSTA	macro
        movf	Areg,W
	endm

TSTB	macro
        movf	Breg,W
	endm

CLRA	macro
	clrf	Areg
	endm

CLRB	macro
	clrf	Breg
	endm

SEC	macro
	bsf	STATUS,C
	endm

CLC	macro
	bcf	STATUS,C
	endm

ROL	macro	var
	rlf	var,F
	endm

ROLA	macro
	rlf	Areg,F
	endm

ROLB	macro
	rlf	Breg,F
	endm

RORA	macro
	rrf	Areg,F
	endm

ASLA	macro
	lslf	Areg,F
	endm

ASLB	macro
	lslf	Breg,F
	endm

ASRB	macro
        asrf	Breg,F
	endm

CBA	macro
	movf	Breg,W
	subwf	Areg,W
	endm

INCB	macro
        incf	Breg,F
	endm

INC	macro	var
        incf	var,F
	endm



